/*!
 * Bootstrap v3.2.0 (http://getbootstrap.com)
 * Copyright 2011-2014 Twitter, Inc.
 * Licensed under MIT (https://github.com/twbs/bootstrap/blob/master/LICENSE)
 */

button::-moz-focus-inner,
input::-moz-focus-inner {
  border: 0;
  padding: 0;
}
textarea {
  overflow: auto;
  width: 475px;
}
textarea.xml {
  overflow:scroll;
  white-space: pre;
  width: 600px;
}
* {
  -webkit-box-sizing: inherit;
  -moz-box-sizing: inherit;
  box-sizing: inherit;
}
*:before,
*:after {
  -webkit-box-sizing: inherit;
  -moz-box-sizing: inherit;
  box-sizing: inherit;
}
.btn {
  display: inline-block;
  margin-bottom: 0;
  font-weight: normal;
  text-align: center;
  vertical-align: middle;
  cursor: pointer;
  background-image: none;
  border: 1px solid transparent;
  white-space: nowrap;
  padding: 6px 12px;
  font-size: 1.3rem;
  line-height: 1.42857143;
  border-radius: 4px;
  -webkit-user-select: none;
  -moz-user-select: none;
  -ms-user-select: none;
  user-select: none;
}
.btn:focus,
.btn:active:focus,
.btn.active:focus {
  outline: thin dotted;
  outline: 5px auto -webkit-focus-ring-color;
  outline-offset: -2px;
}
.btn:hover,
.btn:focus {
  color: #333333;
  text-decoration: none;
}
.btn:active,
.btn.active {
  outline: 0;
  background-image: none;
  -webkit-box-shadow: inset 0 3px 5px rgba(0, 0, 0, 0.125);
  box-shadow: inset 0 3px 5px rgba(0, 0, 0, 0.125);
}
.btn.disabled,
.btn[disabled],
fieldset[disabled] .btn {
  cursor: not-allowed;
  pointer-events: none;
  opacity: 0.65;
  filter: alpha(opacity=65);
  -webkit-box-shadow: none;
  box-shadow: none;
}
.btn-default {
  color: #333333;
  background-color: #E1E1E1;
  border-color: #cccccc;
}
.btn-default:hover,
.btn-default:focus,
.btn-default:active,
.btn-default.active,
.open > .dropdown-toggle.btn-default {
  color: #333333;
  background-color: #e6e6e6;
  border-color: #adadad;
}
.btn-default:active,
.btn-default.active,
.open > .dropdown-toggle.btn-default {
  background-image: none;
}
.btn-default.disabled,
.btn-default[disabled],
fieldset[disabled] .btn-default,
.btn-default.disabled:hover,
.btn-default[disabled]:hover,
fieldset[disabled] .btn-default:hover,
.btn-default.disabled:focus,
.btn-default[disabled]:focus,
fieldset[disabled] .btn-default:focus,
.btn-default.disabled:active,
.btn-default[disabled]:active,
fieldset[disabled] .btn-default:active,
.btn-default.disabled.active,
.btn-default[disabled].active,
fieldset[disabled] .btn-default.active {
  background-color: #ffffff;
  border-color: #cccccc;
}
.btn-default .badge {
  color: #ffffff;
  background-color: #333333;
}
.btn-dynamix {
  color: inherit;
  background-color: inherit;
  border-color: inherit;
}
.btn-dynamix:hover,
.btn-dynamix:focus,
.btn-dynamix:active,
.btn-dynamix.active,
.open > .dropdown-toggle.btn-dynamix {
  color: inherit;
  background-color: inherit;
  border-color: inherit;
}
.btn-dynamix:active,
.btn-dynamix.active,
.open > .dropdown-toggle.btn-dynamix {
  background-image: none;
}
.btn-dynamix.disabled,
.btn-dynamix[disabled],
fieldset[disabled] .btn-dynamix,
.btn-dynamix.disabled:hover,
.btn-dynamix[disabled]:hover,
fieldset[disabled] .btn-dynamix:hover,
.btn-dynamix.disabled:focus,
.btn-dynamix[disabled]:focus,
fieldset[disabled] .btn-dynamix:focus,
.btn-dynamix.disabled:active,
.btn-dynamix[disabled]:active,
fieldset[disabled] .btn-dynamix:active,
.btn-dynamix.disabled.active,
.btn-dynamix[disabled].active,
fieldset[disabled] .btn-dynamix.active {
  background-color: inherit;
  border-color: inherit;
}
.btn-dynamix .badge {
  color: inherit;
  background-color: inherit;
}
.btn-primary {
  color: #ffffff;
  background-color: #428bca;
  border-color: #357ebd;
}
.btn-primary:hover,
.btn-primary:focus,
.btn-primary:active,
.btn-primary.active,
.open > .dropdown-toggle.btn-primary {
  color: #ffffff;
  background-color: #3071a9;
  border-color: #285e8e;
}
.btn-primary:active,
.btn-primary.active,
.open > .dropdown-toggle.btn-primary {
  background-image: none;
}
.btn-primary.disabled,
.btn-primary[disabled],
fieldset[disabled] .btn-primary,
.btn-primary.disabled:hover,
.btn-primary[disabled]:hover,
fieldset[disabled] .btn-primary:hover,
.btn-primary.disabled:focus,
.btn-primary[disabled]:focus,
fieldset[disabled] .btn-primary:focus,
.btn-primary.disabled:active,
.btn-primary[disabled]:active,
fieldset[disabled] .btn-primary:active,
.btn-primary.disabled.active,
.btn-primary[disabled].active,
fieldset[disabled] .btn-primary.active {
  background-color: #428bca;
  border-color: #357ebd;
}
.btn-primary .badge {
  color: #428bca;
  background-color: #ffffff;
}
.btn-success {
  color: #ffffff;
  background-color: #5cb85c;
  border-color: #4cae4c;
}
.btn-success:hover,
.btn-success:focus,
.btn-success:active,
.btn-success.active,
.open > .dropdown-toggle.btn-success {
  color: #ffffff;
  background-color: #449d44;
  border-color: #398439;
}
.btn-success:active,
.btn-success.active,
.open > .dropdown-toggle.btn-success {
  background-image: none;
}
.btn-success.disabled,
.btn-success[disabled],
fieldset[disabled] .btn-success,
.btn-success.disabled:hover,
.btn-success[disabled]:hover,
fieldset[disabled] .btn-success:hover,
.btn-success.disabled:focus,
.btn-success[disabled]:focus,
fieldset[disabled] .btn-success:focus,
.btn-success.disabled:active,
.btn-success[disabled]:active,
fieldset[disabled] .btn-success:active,
.btn-success.disabled.active,
.btn-success[disabled].active,
fieldset[disabled] .btn-success.active {
  background-color: #5cb85c;
  border-color: #4cae4c;
}
.btn-success .badge {
  color: #5cb85c;
  background-color: #ffffff;
}
.btn-info {
  color: #ffffff;
  background-color: #5bc0de;
  border-color: #46b8da;
}
.btn-info:hover,
.btn-info:focus,
.btn-info:active,
.btn-info.active,
.open > .dropdown-toggle.btn-info {
  color: #ffffff;
  background-color: #31b0d5;
  border-color: #269abc;
}
.btn-info:active,
.btn-info.active,
.open > .dropdown-toggle.btn-info {
  background-image: none;
}
.btn-info.disabled,
.btn-info[disabled],
fieldset[disabled] .btn-info,
.btn-info.disabled:hover,
.btn-info[disabled]:hover,
fieldset[disabled] .btn-info:hover,
.btn-info.disabled:focus,
.btn-info[disabled]:focus,
fieldset[disabled] .btn-info:focus,
.btn-info.disabled:active,
.btn-info[disabled]:active,
fieldset[disabled] .btn-info:active,
.btn-info.disabled.active,
.btn-info[disabled].active,
fieldset[disabled] .btn-info.active {
  background-color: #5bc0de;
  border-color: #46b8da;
}
.btn-info .badge {
  color: #5bc0de;
  background-color: #ffffff;
}
.btn-warning {
  color: #ffffff;
  background-color: #f0ad4e;
  border-color: #eea236;
}
.btn-warning:hover,
.btn-warning:focus,
.btn-warning:active,
.btn-warning.active,
.open > .dropdown-toggle.btn-warning {
  color: #ffffff;
  background-color: #ec971f;
  border-color: #d58512;
}
.btn-warning:active,
.btn-warning.active,
.open > .dropdown-toggle.btn-warning {
  background-image: none;
}
.btn-warning.disabled,
.btn-warning[disabled],
fieldset[disabled] .btn-warning,
.btn-warning.disabled:hover,
.btn-warning[disabled]:hover,
fieldset[disabled] .btn-warning:hover,
.btn-warning.disabled:focus,
.btn-warning[disabled]:focus,
fieldset[disabled] .btn-warning:focus,
.btn-warning.disabled:active,
.btn-warning[disabled]:active,
fieldset[disabled] .btn-warning:active,
.btn-warning.disabled.active,
.btn-warning[disabled].active,
fieldset[disabled] .btn-warning.active {
  background-color: #f0ad4e;
  border-color: #eea236;
}
.btn-warning .badge {
  color: #f0ad4e;
  background-color: #ffffff;
}
.btn-danger {
  color: #ffffff;
  background-color: #d9534f;
  border-color: #d43f3a;
}
.btn-danger:hover,
.btn-danger:focus,
.btn-danger:active,
.btn-danger.active,
.open > .dropdown-toggle.btn-danger {
  color: #ffffff;
  background-color: #c9302c;
  border-color: #ac2925;
}
.btn-danger:active,
.btn-danger.active,
.open > .dropdown-toggle.btn-danger {
  background-image: none;
}
.btn-danger.disabled,
.btn-danger[disabled],
fieldset[disabled] .btn-danger,
.btn-danger.disabled:hover,
.btn-danger[disabled]:hover,
fieldset[disabled] .btn-danger:hover,
.btn-danger.disabled:focus,
.btn-danger[disabled]:focus,
fieldset[disabled] .btn-danger:focus,
.btn-danger.disabled:active,
.btn-danger[disabled]:active,
fieldset[disabled] .btn-danger:active,
.btn-danger.disabled.active,
.btn-danger[disabled].active,
fieldset[disabled] .btn-danger.active {
  background-color: #d9534f;
  border-color: #d43f3a;
}
.btn-danger .badge {
  color: #d9534f;
  background-color: #ffffff;
}
.btn-link {
  color: #428bca;
  font-weight: normal;
  cursor: pointer;
  border-radius: 0;
}
.btn-link,
.btn-link:active,
.btn-link[disabled],
fieldset[disabled] .btn-link {
  background-color: transparent;
  -webkit-box-shadow: none;
  box-shadow: none;
}
.btn-link,
.btn-link:hover,
.btn-link:focus,
.btn-link:active {
  border-color: transparent;
}
.btn-link:hover,
.btn-link:focus {
  color: #2a6496;
  text-decoration: underline;
  background-color: transparent;
}
.btn-link[disabled]:hover,
fieldset[disabled] .btn-link:hover,
.btn-link[disabled]:focus,
fieldset[disabled] .btn-link:focus {
  color: #777777;
  text-decoration: none;
}
.btn-lg,
.btn-group-lg > .btn {
  padding: 10px 16px;
  font-size: 1.8rem;
  line-height: 1.33;
  border-radius: 6px;
}
.btn-sm,
.btn-group-sm > .btn {
  padding: 5px 10px;
  font-size: 1.1rem;
  line-height: 1.5;
  border-radius: 3px;
  min-width: 13px;
}
.btn-xs,
.btn-group-xs > .btn {
  padding: 1px 5px;
  font-size: 1.1rem;
  line-height: 1.5;
  border-radius: 3px;
}
.btn-block {
  display: block;
  width: 100%;
}
.btn-block + .btn-block {
  margin-top: 5px;
}
input[type="submit"].btn-block,
input[type="reset"].btn-block,
input[type="button"].btn-block {
  width: 100%;
}
.btn-group,
.btn-group-vertical {
  position: relative;
  display: inline-block;
  vertical-align: middle;
}
.btn-group > .btn,
.btn-group-vertical > .btn {
  position: relative;
  float: left;
}
.btn-group > .btn:hover,
.btn-group-vertical > .btn:hover,
.btn-group > .btn:focus,
.btn-group-vertical > .btn:focus,
.btn-group > .btn:active,
.btn-group-vertical > .btn:active,
.btn-group > .btn.active,
.btn-group-vertical > .btn.active {
  z-index: 2;
}
.btn-group > .btn:focus,
.btn-group-vertical > .btn:focus {
  outline: 0;
}
.btn-group .btn + .btn,
.btn-group .btn + .btn-group,
.btn-group .btn-group + .btn,
.btn-group .btn-group + .btn-group {
  margin-left: -1px;
}
.btn-toolbar {
  margin-left: -5px;
}
.btn-toolbar .btn-group,
.btn-toolbar .input-group {
  float: left;
}
.btn-toolbar > .btn,
.btn-toolbar > .btn-group,
.btn-toolbar > .input-group {
  margin-left: 5px;
}
.btn-group > .btn:not(:first-child):not(:last-child):not(.dropdown-toggle) {
  border-radius: 0;
}
.btn-group > .btn:first-child {
  margin-left: 0;
}
.btn-group > .btn:first-child:not(:last-child):not(.dropdown-toggle) {
  border-bottom-right-radius: 0;
  border-top-right-radius: 0;
}
.btn-group > .btn:last-child:not(:first-child),
.btn-group > .dropdown-toggle:not(:first-child) {
  border-bottom-left-radius: 0;
  border-top-left-radius: 0;
}
.btn-group > .btn-group {
  float: left;
}
.btn-group > .btn-group:not(:first-child):not(:last-child) > .btn {
  border-radius: 0;
}
.btn-group > .btn-group:first-child > .btn:last-child,
.btn-group > .btn-group:first-child > .dropdown-toggle {
  border-bottom-right-radius: 0;
  border-top-right-radius: 0;
}
.btn-group > .btn-group:last-child > .btn:first-child {
  border-bottom-left-radius: 0;
  border-top-left-radius: 0;
}
.btn-group .dropdown-toggle:active,
.btn-group.open .dropdown-toggle {
  outline: 0;
}
.btn-group > .btn + .dropdown-toggle {
  padding-left: 8px;
  padding-right: 8px;
}
.btn-group > .btn-lg + .dropdown-toggle {
  padding-left: 12px;
  padding-right: 12px;
}
.btn-group.open .dropdown-toggle {
  -webkit-box-shadow: inset 0 3px 5px rgba(0, 0, 0, 0.125);
  box-shadow: inset 0 3px 5px rgba(0, 0, 0, 0.125);
}
.btn-group.open .dropdown-toggle.btn-link {
  -webkit-box-shadow: none;
  box-shadow: none;
}
.btn .caret {
  margin-left: 0;
}
.btn-lg .caret {
  border-width: 5px 5px 0;
  border-bottom-width: 0;
}
.dropup .btn-lg .caret {
  border-width: 0 5px 5px;
}
.btn-group-vertical > .btn,
.btn-group-vertical > .btn-group,
.btn-group-vertical > .btn-group > .btn {
  display: block;
  float: none;
  width: 100%;
  max-width: 100%;
}
.btn-group-vertical > .btn-group > .btn {
  float: none;
}
.btn-group-vertical > .btn + .btn,
.btn-group-vertical > .btn + .btn-group,
.btn-group-vertical > .btn-group + .btn,
.btn-group-vertical > .btn-group + .btn-group {
  margin-top: -1px;
  margin-left: 0;
}
.btn-group-vertical > .btn:not(:first-child):not(:last-child) {
  border-radius: 0;
}
.btn-group-vertical > .btn:first-child:not(:last-child) {
  border-top-right-radius: 4px;
  border-bottom-right-radius: 0;
  border-bottom-left-radius: 0;
}
.btn-group-vertical > .btn:last-child:not(:first-child) {
  border-bottom-left-radius: 4px;
  border-top-right-radius: 0;
  border-top-left-radius: 0;
}
.btn-group-vertical > .btn-group:not(:first-child):not(:last-child) > .btn {
  border-radius: 0;
}
.btn-group-vertical > .btn-group:first-child:not(:last-child) > .btn:last-child,
.btn-group-vertical > .btn-group:first-child:not(:last-child) > .dropdown-toggle {
  border-bottom-right-radius: 0;
  border-bottom-left-radius: 0;
}
.btn-group-vertical > .btn-group:last-child:not(:first-child) > .btn:first-child {
  border-top-right-radius: 0;
  border-top-left-radius: 0;
}
.btn-group-justified {
  display: table;
  width: 100%;
  table-layout: fixed;
  border-collapse: separate;
}
.btn-group-justified > .btn,
.btn-group-justified > .btn-group {
  float: none;
  display: table-cell;
  width: 1%;
}
.btn-group-justified > .btn-group .btn {
  width: 100%;
}
.btn-group-justified > .btn-group .dropdown-menu {
  left: auto;
}
.clearfix:before,
.clearfix:after,
.btn-toolbar:before,
.btn-toolbar:after,
.btn-group-vertical > .btn-group:before,
.btn-group-vertical > .btn-group:after {
  content: " ";
  display: table;
}
.clearfix:after,
.btn-toolbar:after,
.btn-group-vertical > .btn-group:after {
  clear: both;
}
table.tablesorter.kvm tr:nth-child(odd){background:none;}
table.tablesorter.kvm tr:nth-child(even){background:none;}
table.tablesorter.kvm th:first-child{width:3%;text-align:center;}
table.tablesorter.kvm td:first-child{width:3%;text-align:center;}
table.tablesorter.kvm th:nth-child(2){width:9%;text-align:left;}
table.tablesorter.kvm td:nth-child(2){width:9%;text-align:left;}
table.tablesorter.kvm th:nth-child(3){text-align:left;}
table.tablesorter.kvm td:nth-child(3){text-align:left;}
table.tablesorter.kvm th:nth-child(4){width:5%;text-align:center;}
table.tablesorter.kvm td:nth-child(4){width:5%;text-align:center;}
table.tablesorter.kvm th:nth-child(5){width:9%;text-align:center;}
table.tablesorter.kvm td:nth-child(5){width:9%;text-align:center;}
table.tablesorter.kvm th:nth-child(6){width:9%;text-align:center;}
table.tablesorter.kvm td:nth-child(6){width:9%;text-align:center;}
table.tablesorter.kvm th:nth-child(7){width:9%;text-align:center;}
table.tablesorter.kvm td:nth-child(7){width:9%;text-align:center;}
table.tablesorter.kvm th:nth-child(8){width:80px;text-align:center;}
table.tablesorter.kvm td:nth-child(8){width:80px;text-align:left;}
table.tablesorter.kvm th:nth-child(9){width:24px;text-align:center;}
table.tablesorter.kvm td:nth-child(9){width:24px;text-align:center;}
table.tablesorter.kvm tr>td+td+td+td{width:9%;white-space:nowrap;}
table.tablesorter.kvm-span{margin-top:-20px;}
table.tablesorter.kvm-span tr:nth-child(odd){background:none;}
table.tablesorter.kvm-span tr:nth-child(even){background:none;}
table.tablesorter.dominfo{margin-top: 5px;}
table.tablesorter.dominfo{margin-left:48px;}
table.tablesorter.domdisk{margin-top: 5px;}
table.tablesorter.domdisk{margin-left:72px;}
table.tablesorter.domdisk th:first-child{width:55%;text-align:left;}
table.tablesorter.domdisk td:first-child{width:55%;text-align:left;}
table.tablesorter.domdisk th:nth-child(2){width:10%;text-align:left;}
table.tablesorter.domdisk td:nth-child(2){width:10%;text-align:left;}
table.tablesorter.domdisk th:nth-child(3){width:10%;text-align:left;}
table.tablesorter.domdisk td:nth-child(3){width:10%;text-align:left;}
table.tablesorter.domdisk th:nth-child(4){width:10%;text-align:left;}
table.tablesorter.domdisk td:nth-child(4){width:10%;text-align:left;}
table.tablesorter.domdisk th:nth-child(5){width:15%;text-align:left;}
table.tablesorter.domdisk td:nth-child(5){width:15%;text-align:left;}
table.tablesorter.domdisk tr>td+td+td{width:10%;white-space:nowrap;}
table.tablesorter.domsnap{margin-top: 5px;}
table.tablesorter.domsnap{margin-left:72px;}
table.tablesorter.domsnap th:first-child{width:9%;text-align:left;}
table.tablesorter.domsnap td:first-child{width:9%;text-align:left;}
table.tablesorter.domsnap th:nth-child(2){width:9%;text-align:left;}
table.tablesorter.domsnap td:nth-child(2){width:9%;text-align:left;}
table.tablesorter.domsnap th:nth-child(3){width:9%;text-align:left;}
table.tablesorter.domsnap td:nth-child(3){width:9%;text-align:left;}
table.tablesorter.domsnap th:nth-child(4){width:9%;text-align:left;}
table.tablesorter.domsnap td:nth-child(4){width:9%;text-align:left;}
table.tablesorter.domsnap th:nth-child(5){width:9%;text-align:left;}
table.tablesorter.domsnap td:nth-child(5){width:9%;text-align:left;}
table.tablesorter.domsnap tr>td+td+td{width:9%;white-space:nowrap;}
table.tablesorter.domsnap td:last-child{width:96px;padding:0;}

.iconstatus {
  position: absolute;
  z-index: 2;
  bottom: -4px;
  right: -4px;
  font-size: 1.4rem;
  text-shadow: 0 0 2px #FFF;
}
img.started{opacity: 1.0;}
img.stopped{opacity: 0.3;}
img.paused{opacity: 0.6;}
.started{color:#009900;}
.stopped{color:#EF3D47;}
.paused{color:#F0DD33;}

.log{cursor:zoom-in;}

#memory-slider-range {
    width: 300px;
    margin: 10px 0;
}
#memory-slider-range .ui-slider-range {
    border-radius:0%;
    background: #007cba;
}
#memory-slider-range .ui-slider-handle {
    width: 10px;
    margin: 0px;
    outline: none;
    position: absolute;
}
#memory-slider-range .ui-slider-handle:nth-of-type(1) {
    border-radius: 10px 0 0 10px;
    background: #007cba;
    cursor: pointer;
    transform: translateX(-90%);
}
#memory-slider-range .ui-slider-handle:nth-of-type(2) {
    border-radius: 0 10px 10px 0;
    background: #007cba;
    cursor: pointer;
}

.memory-selects {
    display: flex;
    justify-content: space-between;
    width: 300px;
    margin-top: 5px;
    font-size: 12px;
    color: #666;
}

.memory-selects > div {
    display: flex;
    align-items: center;
    gap: 5px;
}

.memory-selects select {
    min-width: 60px;
    font-size: 12px;
    padding: 2px 5px;
    box-sizing: border-box;
    -webkit-appearance: none;
    -moz-appearance: none;
    appearance: none;
}